---
title: "On the Liberty of the Press"
author: "David Hume"
image: img/david-hume.jpg
era: "Early Modern"
topic: "Free Speech"
draft: false
---

**The following is from a compilation of essays by David Hume (1711 – 1776),** [**preserved on Gutenberg.org**](https://www.gutenberg.org/files/36120/36120-h/36120-h.htm), and posted here to add to my collection of topical arguments.

Nothing is more apt to surprise a foreigner, than the extreme liberty which we enjoy in this country of communicating whatever we please to the public and of openly censuring every measure entered into by the king or his ministers. If the administration resolve upon war, it is affirmed, that, either willfully or ignorantly, they mistake the interests of the nation; and that peace, in the present situation of affairs, is infinitely preferable. If the passion of the ministers lie towards peace, our political writers breathe nothing but war and devastation, and represent the specific conduct of the government as mean and pusillanimous. As this liberty is not indulged in any other government, either republican or monarchical; in Holland and Venice, more than in France or Spain; it may very naturally give occasion to the question, *How it happens that Great Britain alone enjoys this peculiar privilege?*

The reason why the laws indulge us in such a liberty, seems to be derived from our mixed form of government, which is neither wholly monarchical, nor wholly republican. It will be found, if I mistake not, a true observation in politics, that the two extremes in government, liberty and slavery, commonly approach nearest to each other; and that, as you depart from the extremes, and mix a little of monarchy with liberty, the government becomes always the more free; and, on the other hand, when you mix a little of liberty with monarchy, the yoke becomes always the more grievous and intolerable. In a government, such as that of France, which is absolute, and where law, custom, and religion concur, all of them, to make the people fully satisfied with their condition, the monarch cannot entertain any *jealousy* against his subjects, and therefore is apt to indulge them in great *liberties*, both of speech and action. In a government altogether republican, such as that of Holland, where there is no magistrate so eminent as to give *jealousy* to the state, there is no danger in entrusting the magistrates with large discretionary powers; and though many advantages result from such powers, in preserving peace and order, yet they lay a considerable restraint on men’s actions, and make every private citizen pay a great respect to the government. Thus it seems evident, that the two extremes of absolute monarchy and of a republic, approach near to each other in some material circumstances. In the *first*, the magistrate has no jealousy of the people; in the *second*, the people have none of the magistrate: which want of jealousy begets a mutual confidence and trust in both cases, and produces a species of liberty in monarchies, and of arbitrary power in republics.

To justify the other part of the foregoing observation, that, in every government, the means are most wide of each other, and that the mixtures of monarchy and liberty render the yoke either more grievous; I must take notice of a remark in Tacitus with regard to the Romans under the Emperors, that they neither could bear total slavery nor total liberty, *Nec totam servitutem, nec totam libertatem pati possunt.* This remark a celebrated poet has translated and applied to the English, in his lively description of Queen Elizabeth’s policy and government.

> Et fit aimer son joug à l’Anglois indompté,
> Qui ne peut ni servir, ni vivre en liberté.
>
> HENRIADE, liv. i.

According to these remarks, we are to consider the Roman government under the Emperors as a mixture of despotism and liberty, where the despotism prevailed; and the English government as a mixture of the same kind, where the liberty predominates. The consequences are conformable to the foregoing observation, and such as may be expected from those mixed forms of government, which beget a mutual watchfulness and jealousy. The Roman emperors were, many of them, the most frightful tyrants that ever disgraced human nature; and it is evident, that their cruelty was chiefly excited by their *jealousy*, and by their observing that all the great men of Rome bore with impatience the dominion of a family, which, but a little before, was nowise superior to their own. On the other hand, as the republican part of the government prevails in England, though with a great mixture of monarchy, it is obliged, for its own preservation, to maintain a watchful *jealousy* over the magistrates, to remove all discretionary powers, and to secure every one’s life and fortune by general and inflexible laws. No action must be deemed a crime but what the law has plainly determined to be such: no crime must be imputed to a man but from a legal proof before his judges; and even these judges must be his fellow-subjects, who are obliged, by their own interest, to have a watchful eye over the encroachments and violence of the ministers. From these causes it proceeds, that there is as much liberty, and even perhaps licentiousness, in Great Britain, as there were formerly slavery and tyranny in Rome.

These principles account for the great liberty of the press in these kingdoms, beyond what is indulged in any other government. It is apprehended that arbitrary power would steal in upon us, were we not careful to prevent its progress, and were there not any easy method of conveying the alarm from one end of the kingdom to the other. The spirit of the people must frequently be roused, in order to curb the ambition of the court; and the dread of rousing this spirit must be employed to prevent that ambition. Nothing so effectual to this purpose as the liberty of the press; by which all the learning, wit, and genius of the nation, may be employed on the side of freedom, and every one be animated to its defence. As long, therefore, as the republican part of our government can maintain itself against the monarchical, it will naturally be careful to keep the press open, as of importance to its own preservation. [1]

It must however be allowed, that the unbounded liberty of the press, though it be difficult, perhaps impossible, to propose a suitable remedy for it, is one of the evils attending those mixed forms of government.

**~~~**

[1] Since, therefore, the liberty of the press is so essential to the support of our mixed government, this sufficiently decides the second question, *Whether this liberty be advantageous or prejudicial,* there being nothing of greater importance in every state than the preservation of the ancient government, especially if it be a free one. But I would fain go a step further, and assert, that such a liberty is attended with so few inconveniences, that it may be claimed as the common right of mankind, and ought to be indulged them almost in every government except the ecclesiastical, to which, indeed, it would be fatal. We need not dread from this liberty any such ill consequences as followed from the harangues of the popular demagogues of Athens and Tribunes of Rome. A man reads a book or pamphlet alone and coolly. There is none present from whom he can catch the passion by contagion. He is not hurried away by the force and energy of action. And should he be wrought up to never so seditious a humour, there is no violent resolution presented to him by which he can immediately vent his passion. The liberty of the press, therefore, however abused, can scarce ever excite popular tumults or rebellion. And as to those murmurs or secret discontents it may occasion, it is better they should get vent in words, that they may come to the knowledge of the magistrate before it be too late, in order to his providing a remedy against them. Mankind, it is true, have always a greater propension to believe what is said to the disadvantage of their governors than the contrary; but this inclination is inseparable from them whether they have liberty or not. A whisper may fly as quick, and be as pernicious as a pamphlet. Nay, it will be more pernicious, where men are not accustomed to think freely, or distinguish betwixt truth and falsehood.

It has also been found, as the experience of mankind increases, that the *people* are no such dangerous monsters as they have been represented, and that it is in every respect better to guide them like rational creatures than to lead or drive them like brute beasts. Before the United Provinces set the example, toleration was deemed incompatible with good government; and it was thought impossible that a number of religious sects could live together in harmony and peace, and have all of them an equal affection to their common country and to each other. *England* has set a like example of civil liberty; and though this liberty seems to occasion some small ferment at present, it has not as yet produced any pernicious effects; and it is to be hoped that men, being every day more accustomed to the free discussion of public affairs, will improve in their judgment of them, and be with greater difficulty seduced by every idle rumour and popular clamour.

It is a very comfortable reflection to the lovers of liberty, that this peculiar privilege of *Britain* is of a kind that cannot easily be wrested from us, and must last as long as our government remains in any degree free and independent. It is seldom that liberty of any kind is lost all at once. Slavery has so frightful an aspect to men accustomed to freedom, that it must steal in upon them by degrees, and must disguise itself in a thousand shapes in order to be received. But if the liberty of the press ever be lost, it must be lost at once. The general laws against sedition and libelling are at present as strong as they possibly can be made. Nothing can impose a further restraint but either the clapping an imprimatur upon the press, or the giving very large discretionary powers to the court to punish whatever displeases them. But these concessions would be such a barefaced violation of liberty, that they will probably be the last efforts of a despotic government. We may conclude that the liberty of *Britain* is gone for ever when these attempts shall succeed.
