---
title: "Mill Harm Liberty and Censorship"
date: 2019-12-06T11:59:07Z
tags: ["censorship","free speech","harm principle","liberty","human nature"]
topics: ["philosophy"]
image: img/mill-cartoon.jpg
draft: false
---

J.S. Mill’s famous essay *On Liberty* proposes a broadly Utilitarian principle to be applied for the purpose of the preservation of individual liberty against state coercion. This principle is known as the ‘*harm principle*’. Mill provides three vaguely distinct formulations of the principle, and in each one, the term ‘harm’ takes on a slightly different meaning. The first formulation implies a definition of harm as an act which would require either individual or collective ‘self-protection’ as a response. The second, more augmented formulation implies that a harm is an act of either commission or omission, that is hurtful to the ‘interests of others’. The final formulation of the principle implies that a harm is any act which impedes or deprives others’ pursuit of ‘their own good, in their own way’. This essay will first briefly summarize these three formulations, and then assess whether they function as bulwarks of liberty. At that point, I will pivot to examine how the harm principle is incorporated into Mill’s view of free speech in chapter two of the work, and briefly evaluate the strength of his defense against censorship in that context.

The basic formulation of the harm principle says, essentially, that an act of state coercion can only be justified insofar as it prevents any individual from ‘harming’ any other individual. In outlining this formulation, Mill deploys the phrase ‘self-protection’. This gives the meaning of ‘harm’ a very visceral, and very naïve sense, as for example, a simple threat of physical violence. On this reading of the meaning of ‘harm’, the state has a very narrow role to play in society. It is one that suggests a limited responsibility for policing violence, property crime, and not much else. This is perhaps the most libertarian sense of the principle.

The second formulation of the harm principle hints at the famous ‘pursuit of happiness’ right, enumerated in the US Declaration of Independence. This formulation says that a harm is any act which might deprive or impede another individual’s ‘*pursuit of their own good, in their own way*’. For Mill, one’s own good just is one’s happiness as understood in Utilitarian terms. In Utilitarianism, happiness is defined in terms of a variety of “higher pleasure”, akin to a sublime experience, or the satisfaction of a job well done. This is vaguely similar to Aristotle’s Eudaimonia, but leans more heavily on the psychological than Aristotle does. A harm in this context, then, is anything that would reduce the possibility of an individual attaining that kind of happiness. Depriving a child of a satisfactory education, denying access to an institution like political suffrage, or property ownership, might constitute this sort of harm.

The third and final formulation incorporates Mill’s Utilitarianism, suggesting that the ‘greatest good’ is in some way a duty of each citizen in a society, and not solely the state. Paraphrased, this formulation says the state may engage in active coercion when any act by any individual is deemed injurious to the ‘interests of others’. On this interpretation, the ‘interests of others’ is read as a set of legally enumerated rights, that guarantee certain benefits to each individual in the society. This legal enumeration thus places positive obligations on individuals, the failure of which to satisfy, is regarded a ‘harm’ and renders the transgressor subject to punishment by the state. This formulation is thought to justify institutions like the welfare state, and taxation.

Each of the three definitions of harm resides in a context unique to its definition, implying varying degrees of both negative and positive obligations on the part of the individual, and varying degrees and kinds of positive intervention on the part of the state, for the sake of ‘*the greatest happiness*’. The third formulation relies on the state itself to define and enumerate rights (understood as ‘certain interests’), which suggests that the state would end up being the sole arbiter of what constituted an infringement, and thus a ‘harm’. The basic definition of harm seems to rule out any form of harm that does not involve ‘self-protection’. The second formulation leans libertarian, and offers a definition of harm that lacks the clarity of the final more Utilitarian one, but suggests a more prominent and expansive role for rights than the others.

One might imagine the three conceptions as concentric rings contained within each other. The smallest ring being the “self-protection” one. The middle ring being the “libertarian” rights conception. The outermost ring being the utilitarian “welfare” conception. As the rings expand, our responsibilities and obligations expand with them. However, it is also clear to see from this metaphor, that an obvious tension exists between the two inner-most rings, and the outer “welfare” ring. At what point does my pursuit of “my own good, in my own way” stop being the operative principle, and the “general welfare” start being the operative principle? Even between the two inner rings, there is the question of where my self-protection ends and your pursuit of “your own good, in your own way” begins. Mill leaves the boundaries and overlaps between the rings entirely unspecified, even after an entire chapter of practical “applications”. In the end, there does not seem to be an obvious way to reconcile the three definitions found in these formulations of the harm principle, leaving the question of the preservation of liberty an entirely open issue.

\* * * *

Chapter two of On Liberty is J. S. Mill’s attempt to carry the harm principle enumerated in chapter one into the realm of broader public policy, by arguing against the censorship of so-called socially harmful views. Broadly construed, his case is persuasive. However, the force of that persuasion relies upon at least two hidden presuppositions that deny the efficacy of his own pleasure principle, as outlined in Utilitarianism. While the four reasons summarized at the end of On Liberty do depend on the harm principle outlined in chapter one of the book, the harm he is warning us against has nothing to do with a threat to aggregates of pleasure, or even psychological happiness in the collective sense. So, a Platonist or Kantian may find much succor in his reasoning, but a utilitarian is likely to be confused by it.

Mill’s first implicit presupposition reorients the center of his ethics. No longer is happiness in the utilitarian sense (aggregates of pleasure) the *summum bonum*, but truth. The pursuit of truth elevates the moral ‘dignity’ of the individual, and in so doing, maximizes his potential. Being robbed of the opportunity to pursue the truth in an ‘atmosphere of freedom of thought’, then, is a harm in Mill’s second sense of harm, because it is preventing him from satisfying his duty to society and denying him the benefits owed in return. However, not being grounded in utilitarian pleasure makes the premise an alien one. On this view, a society is maximizing its overall well-being when it is maximizing the possibility of every member’s achievement of the “dignity of thinking beings”. That social good is ill-defined and seems independently parallel to his conception of the ‘greatest happiness’ principle found in Utilitarianism. He also diverges dramatically from at least one of his conceptions of ‘harm’ in the previous chapter, by arguing that a certain sort of moral dignity is necessary for happiness, which is only attainable by an elevation of ‘mental stature’, which in turn is only possible through the rigor of the ‘atmosphere of freedom of thought’. The harm, then, would be to strike at the root of this tree, by suppressing or censoring opinion, whatever its valence either moral or ontological.

Mill’s second implicit presupposition is to impose a subtle change in man’s fundamental nature. He is no longer simply an animal (albeit a sophisticated one) in a straightforward, unplanned pursuit of pleasures and avoidances of pains, but a rational being whose purpose is to progress toward the truth. Any state that impedes that progress is thus an illiberal one, and unjustified on the grounds of the harm principle. Given that the freedom of opinion is instrumentally necessary to the pursuit of truth, censorship of opinion would thus constitute a violation of the state’s legitimate authority, because only societies that are in a state of progress toward the truth, can be justly said to be interested in the well-being of their individual members. This certainly gives the harm principle greater importance, because all forms of error and falsehood take on an urgency which they lack under the narrower utilitarian pleasure principle. On this conception of the greatest good, the attainment of ‘one’s own good, in one’s own way’ loses its relativistic character because all paths lead to the truth. Liberty of thought and opinion is instrumentally necessary because without it, the attainment of truth through the clash of free opinions is impossible. Thus, to deny citizens access to the means of attaining truth, is to deny them the means by which they can realize their full potential as ‘progressive beings’ (from chapter one).

If one were to accept these quasi-Aristotelian presuppositions, the four grounds of Freedom of Opinion that Mill provides at the end of chapter two of On Liberty follow fairly easily: (1) The suppression of opinion may suppress the truth, and to insist it won’t is to presume to judge for all what the truth is. (2) The suppression of partial truths, on the basis that they are not the complete truth, prevents the combination and collation of partial truths to arrive at complete truth. (3) The suppression of falsehoods prevents challenges to received actual truths and encourages the dogmatic propagation of received truths. (4) The development of moral character is not possible in a regime in which everyone apes correct opinion as a matter of convention, rather than independent thought. These reasons for opposing censorship are all, still, consequentialist in nature. But none of them rests entirely on the pleasure principle enumerated in Utilitarianism, and they all rest on the harm principle only insofar as they impede access to the truth. So, were one a committed hedonic utilitarian, one would likely not find these reasons very persuasive. Fortunately, there are other grounds for accepting these reasons. So, Mill’s effort is not in vain, in spite of himself.

```[Imported from exitingthecave.com on 29 November 2021]```

